**************************************************************
* This script computes the two-way clustered standard errors *
* reported in Appendix Table B2.                             *
* Note: requires x_ols.ado which implements Kline(2014)      *
**************************************************************

use eventspells.dta

*Check that i can replicate david's resids using ANOVA
anova dws yr#female educ#female educ#female#c.age educ#female#c.agesq

predict yhat

gen gap=dw-yhat

compare gap dwr if samefirm==0


*Now make regressors manually
*note: Stata leaves out "main effect" of continuous variables

xi i.yr i.educ i.educ|age i.educ|agesq

reg dws _I* age agesq if female==1
predict yhatf if female==1
reg dws _I* age agesq if female==0
predict yhatm if female==0
gen gap2=dw-yhatf if female==1
replace gap2=dw-yhatm if female==0

compare gap2 dwr if samefirm==0


*make cross id for two-way clustering
egen crossid=group(lagfirmid firmid)

*Cleanup before loop
keep dw age agesq lagfirmid firmid crossid _I* female qlom lagqlom samefirm

*Loop over all origin destination quartile combinations and gender
*compute point estimates and two-way clustered standard error
*report results in matrix
mat A=J(32,5,.) //empty results matrix
local counter=1
forvalues q=1/4{
	forvalues m=1/4{
		forvalues f=0/1{
cap drop D
gen D=0 if samefirm==1&female==`f'
replace D=1 if qlom==`q'&lagqlom==`m'&female==`f'&samefirm==0
di "Now running `m'-->`q' for female=`f'"
preserve
keep if D!=. //restrict sample to verify Oaxaca routine works
qui x_ols dw _I* age agesq, bo(D) cluster(lagfirmid)
local se1=_se[D]
qui qui x_ols dw _I* age agesq, bo(D) cluster(firmid)
local se2=_se[D]
qui x_ols dw _I* age agesq, bo(D) cluster(crossid)
local se3=_se[D]
local V=(`se1'^2 + `se2'^2 - `se3'^2)
di _b[D]
di sqrt(`V')
mat A[`counter',1]=`m'
mat A[`counter',2]=`q'
mat A[`counter',3]=`f'
mat A[`counter',4]=_b[D]
mat A[`counter',5]=sqrt(`V')
local ++counter
restore
}
}
}

mat list A
svmat A
keep A*
ren A1 originQ
ren A2 destQ
ren A3 female
ren A4 b
ren A5 se
save oaxacaresults, replace

