* decompositions.do - decompositions of firm wage component, for alternative subgroups and under alternative normalizations
* David Card, Ana Rute Cardoso, Patrick Kline
* "Bargaining, Sorting, and the Gender Wage Gap: Quantifying the Impact of Firms on the Relative Pay of Women" 
* QJE 22684

set more 1
program drop _all
capture log close
log using ..\logs\decompositions.log, replace


* double-connected set

use idworker idfirm year lwage fe_m* fe_f* setfirm* setworker* avlVApe avlsalesQPpe ind gender age educ occup1 pink using ..\data\workers_all_info.dta, clear
keep if setfirm==3


* normalize firm fixed effects

foreach g in m f {
	qui sum fe_`g' if avlVApe<2.45  
	gen fe_`g'nva = fe_`g' - r(mean) 

	qui sum fe_`g' if avlsalesQPpe<3.35 
	gen fe_`g'nsal = fe_`g' - r(mean) 

	qui sum fe_`g' if ind==2700  
	gen fe_`g'nhr = fe_`g' - r(mean) 
	
      foreach c in pink blue {
	   qui sum fe_`g'`c' if avlVApe<2.45 
	   gen fe_`g'n`c'va = fe_`g'`c' - r(mean) 
	}
}

* modal occupation

recode occup1 6 8 =68
egen moccup1 = mode(occup1), by(idworker)

save ..\data\tmpdecomps.dta, replace



* decompositions

program define decomps
   use ..\data\tmpdecomps.dta if `1', clear
   collapse lwage fe_mn`2' fe_fn`2', by(gender)

   sort gender
   gen wgap = lwage[1]-lwage[2]
   gen feM_males   = fe_m[1]
   gen feM_females = fe_m[2] 
   gen feF_males   = fe_f[1] 
   gen feF_females = fe_f[2]
 
   gen firm  = feM_males - feF_females
   gen sortm = feM_males - feM_females
   gen sortf = feF_males - feF_females
   gen bargm = feM_males - feF_males
   gen bargf = feM_females - feF_females

   foreach v in firm sortm sortf bargm bargf {
      gen `v'sh = (`v' / wgap)*100
   }

  qui keep if _n==1
  list wgap feM_males feF_females firm firmsh sortm sortmsh sortf sortfsh bargm bargmsh bargf bargfsh, noobs
end


* table 3

decomps "gender!=."         va
decomps "age<=30"           va
decomps "age>=31 & age<=40" va
decomps "age>40"            va

decomps "educ<12"   va
decomps "educ==12"  va
decomps "educ==16"  va


* table 4

decomps "moccup1==1"   va  
decomps "moccup1==2"   va
decomps "moccup1==3"   va
decomps "moccup1==4"   va
decomps "moccup1==5"   va
decomps "moccup1==7"   va
decomps "moccup1==68"  va
decomps "moccup1==9"   va


* table B4

decomps "setfirmpink==3 & setworkerpink==1"  pinkva
decomps "setfirmblue==3 & setworkerblue==1"  blueva


* table B5

decomps "ind==1100"  va
decomps "ind==1400"  va
decomps "ind==1500"  va
decomps "ind==1700"  va
decomps "ind==1800"  va
decomps "ind==1900"  va
decomps "ind==2000"  va
decomps "ind==2100"  va
decomps "ind==2400"  va
decomps "ind==2500"  va
decomps "ind==2600"  va
decomps "ind==2700"  va
decomps "ind==2800"  va
decomps "ind==2900"  va
decomps "ind==3000"  va
decomps "ind==3200"  va
decomps "ind==3300"  va
decomps "ind==3403"  va
decomps "ind==9999"  va


use ..\data\tmpdecomps.dta if setfirm==3, clear
tab ind, missing
tab ind, sum(gender)

gen exp=age-educ-6
gen exp2=exp^2
gen exp3=exp^3

xi, prefix(y) i.year
gen male=1-gender

reg lwage male educ exp exp2 exp3 yyear*

drop if ind==1200 | ind==1300
levelsof ind, local(inds)
foreach i in `inds' {
	qui reg lwage male educ exp exp2 exp3 yyear* if ind==`i'
	display "ind=`i': " _b[male]
}


* table B6 

decomps "gender!=."         hr
decomps "age<=30"           hr
decomps "age>=31 & age<=40" hr
decomps "age>40"            hr

decomps "educ<12"   hr
decomps "educ==12"  hr
decomps "educ==16"  hr


* table D1

decomps "gender!=."         sal
decomps "age<=30"           sal
decomps "age>=31 & age<=40" sal
decomps "age>40"            sal

decomps "educ<12"   sal
decomps "educ==12"  sal
decomps "educ==16"  sal


*** for figure 6

use age gender lwage fe_m fe_f avlVApe setfirm using ..\data\workers_all_info.dta, clear
keep if setfirm==3 

* normalize firm fixed effects

foreach g in m f {
	qui sum fe_`g' if avlVApe<2.45  
	gen fe_`g'nva = fe_`g' - r(mean) 
}

gen dage=age
recode dage 19 20=1920 21 22=2122 23 24=2324 25 26=2526 27 28=2728 29 30 =2930 31 32=3132 33/35=3335 36/38=3638 39/42=3942 43/46=4346 47/50=4750 51/55=5155 56/60=5660 61/65=6165
collapse lwage fe_mn fe_fn, by(dage gender)
save ..\data\for_figure6.dta, replace


log close