* stayers_models.do - estimate stayers models: effect of changes in surplus on the change in wages of stayers
* David Card, Ana Rute Cardoso, Patrick Kline
* "Bargaining, Sorting, and the Gender Wage Gap: Quantifying the Impact of Firms on the Relative Pay of Women" 
* QJE 22684

set more 1
program drop _all
capture log close
log using ..\logs\stayers_models.log, replace


* firm info

use ..\data\firms_all_info.dta, clear


* excess surplus: VA in excess of 2.45 or sales in excess of 3.35

gen excVAy=max(0,lVApe-2.45) if lVApe!=.
gen excSalesy=max(0,lsalesQPpe-3.35) if lsalesQPpe!=.
label variable excVAy    "VApe in excess of 2.45, yearly"
label variable excSalesy "SalesQPpe in excess of 3.35, yearly"


* change vadd or sales, winsorized or not

xtset idfirm year
gen Dvadd0609 = excVAy-L3.excVAy if year==2009
gen Dsales0508 = excSalesy-L3.excSalesy if year==2008

gen Dvadd0609_winsor = Dvadd0609  if Dvadd0609>-.5 & Dvadd0609<.5
replace Dvadd0609_winsor=.5  if Dvadd0609>=.5  & Dvadd0609!=.
replace Dvadd0609_winsor=-.5 if Dvadd0609<=-.5 & Dvadd0609!=.

gen Dsales0508_winsor = Dsales0508  if Dsales0508>-.5 & Dsales0508<.5
replace Dsales0508_winsor=.5  if Dsales0508>=.5  & Dsales0508!=.
replace Dsales0508_winsor=-.5 if Dsales0508<=-.5 & Dsales0508!=.


* firms with non-missing vadd (sales) in all four analysis years

gen tmpva=1 if avlVApe!=. & excVAy!=. & year>=2006 & year<=2009
egen vayrs=total(tmpva), by(idfirm)

gen tmpsal=1 if avlsalesQPpe!=. & excSalesy!=. & year>=2005 & year<=2008
egen salyrs=total(tmpsal), by(idfirm)

preserve
keep if year>=2006 & year<=2009 & vayrs==4
sort idfirm year
by idfirm: gen excVAy06=excVAy[1]
by idfirm: gen excVAy09=excVAy[_N]
keep if year==2009
keep idfirm Dvadd0609* excVAy0*
save ..\data\tmpstayers_Dvadd.dta, replace
restore

keep if year>=2005 & year<=2008 & salyrs==4
keep if year==2008
keep idfirm Dsales0508*
save ..\data\tmpstayers_DSales.dta, replace


* worker info, for regressions using VA

use ..\data\tmpstayers_Dvadd.dta,clear
merge 1:m idfirm using ..\data\workers_all_info.dta
keep if _merge==3


* analysis years

keep if year>=2006 & year<=2009 


* nb. workers by gender in firm initial year

gen m=(gender==0)
gen f=(gender==1)
egen N06m=total(m) if year==2006, by(idfirm)
egen N06f=total(f) if year==2006, by(idfirm)


* only workers observed all four analysis years staying in same firm

bys idworker: keep if _N==4
egen sdfirm=sd(idfirm), by(idworker)
keep if sdfirm==0


* firm has both male and female stayers

egen sdgender=sd(gender), by(idfirm)
keep if sdgender!=0 & sdgender!=.


* w change

xtset idworker year
gen Dlwage0609 = lwage-L3.lwage if year==2009


* initial (2006) age, education, sizeQP, share females, wage

foreach v in age educ sizeQP sharefem lwage  {
	sort idworker year
	by idworker: gen `v'06=`v'[1]
}
gen age2 = age06^2


* final (2009)  wage

sort idworker year
by idworker: gen lwage09=lwage[_N]


* Mills ratios

* allocate N06 to observations in 2009 & keep only 2009

egen N06fs=mean(N06f), by(idfirm)
egen N06ms=mean(N06m), by(idfirm)
drop N06m N06f

keep if year==2009

* nb. stayers by gender in firm

egen Nm=total(m), by(idfirm)
egen Nf=total(f), by(idfirm)
gen Ntot=Nm + Nf

foreach g in m f {
	gen p_`g' = N`g'/N06`g'
	gen z_`g' = invnormal(p_`g')
	gen numerat_`g' = normalden(z_`g')
	gen Mratio`g' = numerat_`g' / p_`g'

	assert p_`g'==1 if Mratio`g'==.
	replace Mratio`g'=0 if p_`g'==1
}


xtset idfirm
keep idfirm idworker Dlwage0609 Dvadd0609* age06 age2 m f Mratio* Ntot gender educ06 sizeQP06 sharefem06 lwage06 lwage09 excVAy06 excVAy09 
save ..\data\stayers_VAregs.dta, replace


* table B10: descriptives job stayers at firms with VA 2006-09

use ..\data\stayers_VAregs.dta if gender==0, clear
bys gender: sum age06 educ06 sizeQP06 sharefem06 lwage06 lwage09 excVAy06 excVAy09
codebook idworker idfirm

use ..\data\stayers_VAregs.dta if gender==1, clear
bys gender: sum age06 educ06 sizeQP06 sharefem06 lwage06 lwage09 excVAy06 excVAy09
codebook idworker idfirm


* worker info, for regressions using Sales

use ..\data\tmpstayers_DSales.dta,clear
merge 1:m idfirm using ..\data\workers_all_info.dta
keep if _merge==3


* analysis years

keep if year>=2005 & year<=2008


* nb. workers by gender in firm initial year

gen m=(gender==0)
gen f=(gender==1)
egen N05m=total(m) if year==2005, by(idfirm)
egen N05f=total(f) if year==2005, by(idfirm)


* only workers observed all analysis years staying in same firm

bys idworker: keep if _N==4
egen sdfirm=sd(idfirm), by(idworker)
keep if sdfirm==0


* firm has both male and female stayers

egen sdgender=sd(gender), by(idfirm)
keep if sdgender!=0 & sdgender!=.


* w change

xtset idworker year
gen Dlwage0508 = lwage-L3.lwage if year==2008


* initial age

sort idworker year
by idworker: gen age05=age[1]

gen age2 = age05^2


* Mills ratios

* allocate N05 to observations in 2008 & keep only 2008

egen N05fs=mean(N05f), by(idfirm)
egen N05ms=mean(N05m), by(idfirm)
drop N05m N05f

keep if year==2008

* nb. stayers by gender in firm

egen Nm=total(m), by(idfirm)
egen Nf=total(f), by(idfirm)
gen Ntot=Nm + Nf

foreach g in m f {
	gen p_`g' = N`g'/N05`g'
	gen z_`g' = invnormal(p_`g')
	gen numerat_`g' = normalden(z_`g')
	gen Mratio`g' = numerat_`g' / p_`g'

	assert p_`g'==1 if Mratio`g'==.
	replace Mratio`g'=0 if p_`g'==1
}

xtset idfirm
keep idfirm idworker Dlwage0508 Dsales0508* age05 age2 m f Mratio* Ntot
save ..\data\stayers_Salesregs.dta, replace


* regressions stayers

* table 6

use ..\data\stayers_VAregs.dta, clear
	
foreach g in m f {
	qui xtreg Dlwage0609 age06 age2 if `g'==1, fe cluster(idfirm) 
	predict delta_`g', u
}

collapse delta_m delta_f Dvadd0609 Dvadd0609_winsor Ntot, by(idfirm)

* row 1

regress delta_f Dvadd0609_winsor [aweight=Ntot], robust
ivregress 2sls delta_f (delta_m=Dvadd0609_winsor) [aweight=Ntot], first vce(robust)

* row 2

regress delta_f Dvadd0609 [aweight=Ntot], robust
ivregress 2sls delta_f (delta_m=Dvadd0609) [aweight=Ntot], first vce(robust)

* row 3

use ..\data\stayers_Salesregs.dta, clear
	
foreach g in m f {
	qui xtreg Dlwage0508 age05 age2 if `g'==1, fe cluster(idfirm) 
	predict delta_`g', u
}

collapse delta_m delta_f Dsales0508_winsor Ntot, by(idfirm)
regress delta_f Dsales0508_winsor [aweight=Ntot], robust
ivregress 2sls delta_f (delta_m=Dsales0508_winsor) [aweight=Ntot], first vce(robust)


* table B11 
* rows 2 and 3 (row 1 same as table 6)

use ..\data\stayers_VAregs.dta, clear

xtset idfirm
foreach g in m f {
	qui xtreg Dlwage0609 age06 age2 if `g'==1, fe cluster(idfirm) 
	predict delta_`g', u
}

collapse delta_m delta_f Dvadd0609_winsor Mratiom Mratiof Ntot, by(idfirm)

regress delta_f Mratiof Dvadd0609_winsor [aweight=Ntot], robust
ivregress 2sls delta_f Mratiof (delta_m=Dvadd0609_winsor) [aweight=Ntot], first vce(robust)


log close