* hours_models.do -  relationship between gender-specific firm effects and hours of work
* David Card, Ana Rute Cardoso, Patrick Kline
* "Bargaining, Sorting, and the Gender Wage Gap: Quantifying the Impact of Firms on the Relative Pay of Women" 
* QJE 22684

set more 1
program drop _all
capture log close
log using ..\logs\hours_models.log, replace


* hours of work

use ..\data\workers_all_info.dta if setfirm==3, clear

gen hnorm_m=hnorm if gender==0
gen hnorm_f=hnorm if gender==1

gen htot=hnorm+hextra
gen htot_m=htot if gender==0
gen htot_f=htot if gender==1

foreach g in m f {
	egen avh_`g' = mean(htot_`g'), by(idfirm)
	gen lavh_`g' = log(avh_`g')

	egen avhnorm_`g' = mean(hnorm_`g'), by(idfirm)
	gen lavhnorm_`g' = log(avhnorm_`g')
}


* industry dummy vars.

xi, prefix(i) i.ind


* table B7

* panel A

regress fe_m  lavhnorm_m, first cluster(idfirm)
ivregress 2sls fe_m  (lavhnorm_m=lavhnorm_f), first cluster(idfirm)

regress fe_m  iind* lavhnorm_m, first cluster(idfirm)
ivregress 2sls fe_m  iind* (lavhnorm_m=lavhnorm_f), first cluster(idfirm)

regress fe_f  lavhnorm_f, first cluster(idfirm)
ivregress 2sls fe_f  (lavhnorm_f=lavhnorm_m), first cluster(idfirm)

regress fe_f  iind* lavhnorm_f, first cluster(idfirm)
ivregress 2sls fe_f  iind* (lavhnorm_f=lavhnorm_m), first cluster(idfirm)


* panel B

regress fe_m  lavh_m, first cluster(idfirm)
ivregress 2sls fe_m  (lavh_m=lavh_f), first cluster(idfirm)

regress fe_m  iind* lavh_m, first cluster(idfirm)
ivregress 2sls fe_m  iind* (lavh_m=lavh_f), first cluster(idfirm)

regress fe_f  lavh_f, first cluster(idfirm)
ivregress 2sls fe_f  (lavh_f=lavh_m), first cluster(idfirm)

regress fe_f  iind* lavh_f, first cluster(idfirm)
ivregress 2sls fe_f  iind* (lavh_f=lavh_m), first cluster(idfirm)

codebook idfirm

log close

